==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/CinderVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CinderVolumeSourceFluent<A extends io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getFsType();
  public A withFsType(java.lang.String fsType);
  public java.lang.Boolean hasFsType();
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0);
  public java.lang.Boolean getReadOnly();
  public A withReadOnly(java.lang.Boolean readOnly);
  public java.lang.Boolean hasReadOnly();
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LocalObjectReference getSecretRef();
  public io.fabric8.kubernetes.api.model.LocalObjectReference buildSecretRef();
  public A withSecretRef(io.fabric8.kubernetes.api.model.LocalObjectReference secretRef);
  public java.lang.Boolean hasSecretRef();
  public A withNewSecretRef(java.lang.String name);
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> editSecretRef();
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public java.lang.String getVolumeID();
  public A withVolumeID(java.lang.String volumeID);
  public java.lang.Boolean hasVolumeID();
  
  /**
   * Method is deprecated. use withVolumeID instead.
   */
  @java.lang.Deprecated
  public A withNewVolumeID(java.lang.String arg0);
  public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent<io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<N>>{
    public N and();
    public N endSecretRef();
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/CinderVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CinderVolumeSourceFluent<A extends io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getFsType();
  public A withFsType(java.lang.String fsType);
  public java.lang.Boolean hasFsType();
  
  /**
   * Method is deprecated. use withFsType instead.
   */
  @java.lang.Deprecated
  public A withNewFsType(java.lang.String arg0);
  public java.lang.Boolean getReadOnly();
  public A withReadOnly(java.lang.Boolean readOnly);
  public java.lang.Boolean hasReadOnly();
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LocalObjectReference getSecretRef();
  public io.fabric8.kubernetes.api.model.LocalObjectReference buildSecretRef();
  public A withSecretRef(io.fabric8.kubernetes.api.model.LocalObjectReference secretRef);
  public java.lang.Boolean hasSecretRef();
  public A withNewSecretRef(java.lang.String name);
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> editSecretRef();
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
  public io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public java.lang.String getVolumeID();
  public A withVolumeID(java.lang.String volumeID);
  public java.lang.Boolean hasVolumeID();
  
  /**
   * Method is deprecated. use withVolumeID instead.
   */
  @java.lang.Deprecated
  public A withNewVolumeID(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent<io.fabric8.kubernetes.api.model.CinderVolumeSourceFluent.SecretRefNested<N>>{
    public N and();
    public N endSecretRef();
    
  }
  
}
